summaryrefslogtreecommitdiffstats
path: root/konsole/konsole/TEmulation.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsole/konsole/TEmulation.cpp')
-rw-r--r--konsole/konsole/TEmulation.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/konsole/konsole/TEmulation.cpp b/konsole/konsole/TEmulation.cpp
index 39aeab542..e136c3c38 100644
--- a/konsole/konsole/TEmulation.cpp
+++ b/konsole/konsole/TEmulation.cpp
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
// process application unicode input to terminal
// this is a trivial scanner
{
c &= 0xff;
@@ -284,10 +284,10 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
scr->setHistCursor(scr->getHistLines());
if (!ev->text().isEmpty())
{ // A block of text
// Note that the text is proper unicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.
- emit sndBlock(ev->text().ascii(),ev->text().length());
+ emit sndBlock(TQString(ev->text()).ascii(),ev->text().length());
}
else if (ev->ascii()>0)
{ unsigned char c[1];
@@ -299,7 +299,7 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
// Unblocking, Byte to Unicode translation --------------------------------- --
/*
- We are doing code conversion from locale to unicode first.
+ We are doing code conversion from locale to tqunicode first.
*/
void TEmulation::onRcvBlock(const char *s, int len)
@@ -345,7 +345,7 @@ void TEmulation::onRcvBlock(const char *s, int len)
if (r[j].category() == TQChar::Mark_NonSpacing)
scr->compose(r.mid(j,1));
else
- onRcvChar(r[j].unicode());
+ onRcvChar(r[j].tqunicode());
}
i = l;
}
@@ -418,9 +418,9 @@ bool TEmulation::findTextNext( const TQString &str, bool forward, bool caseSensi
for (int i = (m_findPos==-1?0:m_findPos+1); i<(scr->getHistLines()+scr->getLines()); i++) {
string = scr->getHistoryLine(i);
if (regExp)
- pos = string.find( TQRegExp(str,caseSensitive) );
+ pos = string.tqfind( TQRegExp(str,caseSensitive) );
else
- pos = string.find(str, 0, caseSensitive);
+ pos = string.tqfind(str, 0, caseSensitive);
if(pos!=-1) {
m_findPos=i;
if(i>scr->getHistLines())
@@ -436,9 +436,9 @@ bool TEmulation::findTextNext( const TQString &str, bool forward, bool caseSensi
for(int i = (m_findPos==-1?(scr->getHistLines()+scr->getLines()):m_findPos-1); i>=0; i--) {
string = scr->getHistoryLine(i);
if (regExp)
- pos = string.find( TQRegExp(str,caseSensitive) );
+ pos = string.tqfind( TQRegExp(str,caseSensitive) );
else
- pos = string.find(str, 0, caseSensitive);
+ pos = string.tqfind(str, 0, caseSensitive);
if(pos!=-1) {
m_findPos=i;
if(i>scr->getHistLines())
@@ -251,7 +251,7 @@ int TEmulation::keymapNo()
*/
void TEmulation::onRcvChar(int c)
-// process application unicode input to terminal
+// process application tqunicode input to terminal
// this is a trivial scanner
{
@@ -284,10 +284,10 @@ void TEmulation::onKeyPress( TQKeyEvent* ev )
if (!ev->text().isEmpty())
{ // A block of text
- // Note that the text is proper unicode.
+ // Note that the text is proper tqunicode.
// We should do a conversion here, but since this
// routine will never be used, we simply emit plain ascii.